0.9.9 API documentation: fast_square_root.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

fast_square_root.hpp
Go to the documentation of this file.
1
15 #pragma once
16
17 // Dependency:
18 #include "../common.hpp"
19 #include "../exponential.hpp"
20 #include "../geometric.hpp"
21
22 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
23 # ifndef GLM_ENABLE_EXPERIMENTAL
24 # pragma message("GLM: GLM_GTX_fast_square_root is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
25 # else
26 # pragma message("GLM: GLM_GTX_fast_square_root extension included")
27 # endif
28 #endif
29
30 namespace glm
31 {
34
38 template<typename genType>
39 GLM_FUNC_DECL genType fastSqrt(genType x);
40
44 template<length_t L, typename T, qualifier Q>
45 GLM_FUNC_DECL vec<L, T, Q> fastSqrt(vec<L, T, Q> const& x);
46
50 template<typename genType>
51 GLM_FUNC_DECL genType fastInverseSqrt(genType x);
52
56 template<length_t L, typename T, qualifier Q>
57 GLM_FUNC_DECL vec<L, T, Q> fastInverseSqrt(vec<L, T, Q> const& x);
58
62 template<typename genType>
63 GLM_FUNC_DECL genType fastLength(genType x);
64
68 template<length_t L, typename T, qualifier Q>
69 GLM_FUNC_DECL T fastLength(vec<L, T, Q> const& x);
70
74 template<typename genType>
75 GLM_FUNC_DECL genType fastDistance(genType x, genType y);
76
80 template<length_t L, typename T, qualifier Q>
81 GLM_FUNC_DECL T fastDistance(vec<L, T, Q> const& x, vec<L, T, Q> const& y);
82
86 template<typename genType>
87 GLM_FUNC_DECL genType fastNormalize(genType const& x);
88
90 }// namespace glm
91
92 #include "fast_square_root.inl"
glm::fastLength
GLM_FUNC_DECL T fastLength(vec< L, T, Q > const &x)
Faster than the common length function but less accurate.
glm::fastDistance
GLM_FUNC_DECL T fastDistance(vec< L, T, Q > const &x, vec< L, T, Q > const &y)
Faster than the common distance function but less accurate.
glm::fastSqrt
GLM_FUNC_DECL vec< L, T, Q > fastSqrt(vec< L, T, Q > const &x)
Faster than the common sqrt function but less accurate.
glm::fastNormalize
GLM_FUNC_DECL genType fastNormalize(genType const &x)
Faster than the common normalize function but less accurate.
glm::fastInverseSqrt
GLM_FUNC_DECL vec< L, T, Q > fastInverseSqrt(vec< L, T, Q > const &x)
Faster than the common inversesqrt function but less accurate.
glm
Definition: common.hpp:20